@@ -110,6 +110,8 @@ class NetworkBase:
         except OSError:
             self.uselocal = False
 
+        self._io_client = None
+
         gc.collect()
 
     def neo_status(self, value):
@@ -341,8 +343,12 @@ class NetworkBase:
                 print("Could not connect to internet", error)
                 print("Retrying in 3 seconds...")
                 time.sleep(3)
+            gc.collect()
 
     def _get_io_client(self):
+        if self._io_client is not None:
+            return self._io_client
+
         self.connect()
 
         try:
@@ -353,7 +359,8 @@ class NetworkBase:
                 "Adafruit IO secrets are kept in secrets.py, please add them there!\n\n"
             ) from KeyError
 
-        return IO_HTTP(aio_username, aio_key, self._wifi.requests)
+        self._io_client = IO_HTTP(aio_username, aio_key, self._wifi.requests)
+        return self._io_client
 
     def push_to_io(self, feed_key, data):
         """Push data to an adafruit.io feed
@@ -440,7 +447,7 @@ class NetworkBase:
         """Fetch data from the specified url and return a response object
 
         :param str url: The URL to fetch from.
-        :param list headers: Extra headers to include in the request.
+        :param dict headers: Extra headers to include in the request.
         :param int timeout: The timeout period in seconds.
 
         """
@@ -531,7 +538,7 @@ class NetworkBase:
         """Fetch data from the specified url and perfom any parsing
 
         :param str url: The URL to fetch from.
-        :param list headers: Extra headers to include in the request.
+        :param dict headers: Extra headers to include in the request.
         :param json_path: The path to drill down into the JSON data.
         :param regexp_path: The path formatted as a regular expression to search
                             the text data.
